@@ -1,8 +1,9 @@
 package WebService::Braintree;
-$WebService::Braintree::VERSION = '1.0';
+$WebService::Braintree::VERSION = '1.1';
 use 5.010_001;
 use strictures 1;
 
+use WebService::Braintree::AchMandate;
 use WebService::Braintree::Address;
 use WebService::Braintree::AddOn;
 use WebService::Braintree::AdvancedSearchFields;
@@ -10,13 +11,18 @@ use WebService::Braintree::AdvancedSearchNodes;
 use WebService::Braintree::ApplePay;
 use WebService::Braintree::ApplePayCard;
 use WebService::Braintree::CreditCard;
+use WebService::Braintree::CreditCardVerification;
 use WebService::Braintree::Customer;
 use WebService::Braintree::CustomerSearch;
 use WebService::Braintree::DisbursementDetails;
 use WebService::Braintree::Discount;
 use WebService::Braintree::Dispute;
 use WebService::Braintree::DisputeSearch;
+use WebService::Braintree::DocumentUpload;
 use WebService::Braintree::ErrorCodes;
+use WebService::Braintree::EuropeBankAccount;
+use WebService::Braintree::IbanBankAccount;
+use WebService::Braintree::IdealPayment;
 use WebService::Braintree::Merchant;
 use WebService::Braintree::MerchantAccount;
 use WebService::Braintree::PartnerMerchant;
@@ -31,6 +37,7 @@ use WebService::Braintree::Transaction;
 use WebService::Braintree::TransactionSearch;
 use WebService::Braintree::Disbursement;
 use WebService::Braintree::TransparentRedirect;
+use WebService::Braintree::UsBankAccount;
 use WebService::Braintree::WebhookNotification;
 use WebService::Braintree::WebhookTesting;
 
@@ -58,7 +65,7 @@ L<https://developers.braintreepayments.com/ruby/sdk/server/overview>.
 
 You can also look over the test suite for guidance of usage, especially the
 C<xt/sandbox> tests.  Not all of these tests work (ones marked
-C<todo_skip>.  This is because they are an adaptation of code used against
+C<todo_skip>).  This is because they are an adaptation of code used against
 Braintree's private integration server.
 
 As of version 0.94, with appropriate manual intervention for your sandbox
@@ -142,6 +149,14 @@ List all plan discounts.
 
 Accept, and find disputes.
 
+=head3 L<WebService::Braintree::EuropeBankAccount>
+
+Find Europe Bank Accounts.
+
+=head3 L<WebService::Braintree::IdealPayment>
+
+Find IdealPayment payment methods.
+
 =head3 L<WebService::Braintree::Merchant>
 
 Provision merchants from "raw ApplePay".
@@ -181,6 +196,10 @@ Manage the transparent redirection of ????.
 
 B<NOTE>: This class needs significant help in documentation.
 
+=head3 L<WebService::Braintree::UsBankAccount>
+
+Find US Bank Accounts.
+
 =head2 SEARCHING
 
 Several of the class interfaces provide a C<< search() >> method.  This method
